import { ref, onMounted, onUnmounted, computed, reactive, toRefs } from 'vue';
import axios from 'axios';

function useCount(cnount) {
    const num = ref(cnount);
    let timer = null;
    // 开始
    function startTimer() {
        console.log(1);
        clearInterval(timer);
        timer = setInterval(() => {
            num.value--;
            if (num.value <= 0) {
                setInterval(timer);
            }
        }, 1000);
    }
    // 暂停
    function stopTimer() {
        clearInterval(timer);
    }
    //组件挂载完毕
    onMounted(() => {
        startTimer();
    }),
        // 组件卸载
        onUnmounted(() => {
            stopTimer();
        });
    return {
        num: num,
        startTimer,
        stopTimer
    };
}

function useFormValidator() {
    const username = ref("");
    const password = ref("");
    const isUsernameValid = computed(() => username.value.length >= 6);
    const isPasswordValid = computed(() => password.value.length >= 8);
    function handleSubmit() {
        if (isUsernameValid.value && isPasswordValid.value) {
            // 执行提交操作
            console.log("表单提交成功！");
        }
        else {
            // 表单验证失败
            console.log("表单验证失败！");
        }
    }
    return {
        username,
        password,
        isUsernameValid,
        isPasswordValid,
        handleSubmit,
    };
}

function usePosition() {
    // 声明响应式变量
    const move = reactive({
        moveX: 0,
        moveY: 0 //鼠标Y轴
    });
    // 解构
    const { moveX, moveY } = toRefs(move);
    // 定义一个方法通过e这个属性获取鼠标离页面的(X,Y)的位置
    const onMouseMove = (e) => {
        moveX.value = e.pageX;
        moveY.value = e.pageY;
    };
    //组件挂载完毕
    onMounted(() => {
        document.addEventListener('mousemove', onMouseMove);
    }),
        // 组件卸载
        onUnmounted(() => {
            document.removeEventListener('mousemove', onMouseMove);
        });
    // 返回响应式变量
    return {
        moveX,
        moveY
    };
}

function useRequest(url) {
    console.log("请求地址", url);
    /* 定义响应式数据 */
    const loading = ref(false); //用来模式loading效果
    const data = ref(null); //响应式DATA数据
    const error = ref(null); //报错
    // let source = null;
    //当调用这个fetch这个方法时将loading变为true
    async function fetchData() {
        loading.value = true;
        error.value = null;
        data.value = null;
        try {
            // 创建一个请求取消令牌
            // source = axios.CancelToken.source();
            // const response = await axios.get(url, { cancelToken: source.token });
            //响应数据拿到url地址
            const response = await axios.get(url);
            // 模拟响应
            data.value = await new Promise(resolve => {
                setTimeout(() => {
                    resolve(response.data);
                }, 3000);
            });
        }
        catch (error) {
            console.log(error);
            // 报错的时候响应完loading为假
            loading.value = false;
        }
        finally {
            loading.value = false;
        }
    }
    // 在组件挂载时发起请求
    onMounted(() => {
        fetchData();
    });
    // 在组件卸载时取消请求
    onUnmounted(() => {
        fetchData();
    });
    return {
        data,
        loading,
        error,
        fetchData, //获取数据方法
    };
}

export { useCount as useCountdown, useFormValidator, usePosition as useMousePosition, useRequest };
//# sourceMappingURL=bundle.es.js.map
